@@ -20,6 +20,7 @@
 
 #include <array>
 
+#include "katemodelinecompletion.h"
 #include "katetextfolding.h"
 #include "katetextrange.h"
 
@@ -313,7 +314,7 @@ public:
 public:
     /**
      * Try to fold an unfolded range starting at @p line
-     * @return the new folded range on success, otherwise an unvalid range
+     * @return the new folded range on success, otherwise an invalid range
      */
     KTextEditor::Range foldLine(int line);
 
@@ -960,6 +961,8 @@ private:
 public:
     bool insertTemplateInternal(const KTextEditor::Cursor insertPosition, const QString &templateString, const QString &script = QString());
 
+    bool evaluateScriptInternal(const QString &script, QVariant *result = nullptr);
+
     /**
      * Accessors to the bars...
      */
@@ -1166,7 +1169,7 @@ public:
     }
 
     /**
-     * Toogle status bar, e.g. create or remove it
+     * Toggle status bar, e.g. create or remove it
      */
     void toggleStatusBar();
 
